#!/usr/bin/env python
#
# A library for Eliq Online API
# 6d66
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser Public License for more details.
#
# You should have received a copy of the GNU Lesser Public License
# along with this program.  If not, see [http://www.gnu.org/licenses/].

from requests import Session
from requests.compat import urljoin
import datetime


# Base url to Eliq Online API
BASE_URL = "https://my.eliq.io/api/"

# Date format for url
DATE_FORMAT = "%Y-%m-%d %H:%M:%S"


class API(object):
    """ API class for Eliq Online API  """

    INTERVAL_6MIN = "6min"
    INTERVAL_DAY = "day"

    def __init__(self, access_token):
        self._session = Session()
        self._access_token = access_token

    def _request_data(self, function, parameters=None, channelid=None):
        if not parameters:
            parameters = {}

        api_url = urljoin(
            BASE_URL,
            function,
        )

        parameters.update(accesstoken=self._access_token)

        if channelid:
            parameters.update(channelid=channelid)

        return self._session.get(api_url, params=parameters).json()

    def get_data(self, startdate, intervaltype, enddate=None, channelid=None):
        """
        Args:
            startdate (datetime):
            intervaltype (str):
                day
                6min
            enddate (datetime): optional
            channelid (int): optinal

        Returns:
            eliqonline.data
        """

        if isinstance(startdate, datetime.date):
            startdate = startdate.strftime(DATE_FORMAT)

        if isinstance(enddate, datetime.date):
            enddate = enddate.strftime(DATE_FORMAT)

        parameters = dict(startdate=startdate,
                          intervaltype=intervaltype)

        if enddate:
            parameters.update(enddate=enddate)

        return self._request_data('data', parameters, channelid=channelid)

    def get_data_now(self, channelid=None):
        """
        Args:
            channelid (int)

        Returns:
            eliqonline.datanow
        """
        return self._request_data('datanow', channelid=channelid)



#!/usr/bin/env python

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
import io
import os
import re


def read(*names, **kwargs):
    with io.open(
        os.path.join(os.path.dirname(__file__), *names),
        encoding=kwargs.get("encoding", "utf8")
    ) as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


def get_download_url(version):
    return "https://github.com/6d66/eliq/tarball/%s" % version

version = find_version("eliqonline", "__init__.py")
package_name = "eliqonline"

setup(
    name=package_name,
    packages=[package_name],
    version=find_version(package_name, "__init__.py"),
    description='Eliq Online API Library',
    author='6d66',
    author_email='',
    url='https://github.com/6d66/eliq/',
    download_url=get_download_url(version),
    install_requires=list(
        open('requirements.txt').read().strip().split()),
    keywords=['Eliq', 'Eliq Online', 'Eliq Online API'],
    classifiers=[],
)



#!/usr/bin/env python
"""
ELIQ Online

Usage:
  eliq (-h | --help)
  eliq --version
  eliq [-v|-vv] [options] now
  eliq [-v|-vv] [options] today
  eliq [-v|-vv] [options] week
  eliq [-v|-vv] [options] month
  eliq [-v|-vv] [options] year

Options:
  -t <token>      Access token
  -h --help             Show this message
  -v,-vv                Increase verbosity
  --version             Show version
"""

import docopt
import logging
from sys import stderr
from os.path import join, expanduser
from os import environ as env
from yaml import safe_load as load_yaml
from datetime import datetime, timedelta

from eliqonline import API, __version__

LOGFMT = "%(asctime)s %(levelname)5s (%(threadName)s) [%(name)s] %(message)s"
DATEFMT = "%y-%m-%d %H:%M.%S"
LOG_LEVEL = logging.DEBUG
_LOGGER = logging.getLogger(__name__)


# $HOME/.eliqonline and $HOME/.config/eliqonline.conf
CONFIG_FILES = (
    (expanduser('~'), '.eliqonline'),
    (env.get('XDG_CONFIG_HOME',
             join(expanduser('~'), '.config')), 'eliqonline.conf'))


def read_config():
    for directory, filename in CONFIG_FILES:
        try:
            config = join(directory, filename)
            with open(config) as config:
                _LOGGER.debug('Found config file %s', config.name)
                return load_yaml(config)
        except (IOError, OSError):
            continue
    return {}


if __name__ == "__main__":
    args = docopt.docopt(__doc__,
                         version=__version__)

    log_level = [logging.ERROR, logging.INFO, logging.DEBUG][args['-v']]
    logging.basicConfig(level=log_level,
                        stream=stderr,
                        datefmt=DATEFMT,
                        format=LOGFMT)

    config = read_config()
    access_token = args.get('-t') or config.get('accesstoken')
    api = API(access_token=access_token)

    now = datetime.now()

    if args['now']:
        power = api.get_data_now()['power']
        print('Current power: %d kw' % power)
        exit()

    if args['today']:
        intervaltype = api.INTERVAL_6MIN
        startdate = datetime(year=now.year, month=now.month, day=now.day)
        enddate = datetime(year=now.year, month=now.month, day=now.day,
                           hour=23, minute=59, second=59)
    else:
        intervaltype = api.INTERVAL_DAY
        enddate = now
        if args['week']:
            startdate = datetime(year=now.year,
                                 month=now.month,
                                 day=now.day) - timedelta(days=7)
        elif args['month']:
            startdate = datetime(year=now.year, month=now.month, day=1)
        elif args['year']:
            startdate = datetime(year=now.year, month=1, day=1)

    data = api.get_data(startdate=startdate, enddate=enddate,
                        intervaltype=intervaltype)

    for item_data in data['data']:
        print("%s - %s: average power: %4s W" % (
            item_data['time_start'],
            item_data['time_end'],
            str(int(item_data['avgpower'])) if item_data['avgpower'] else '?'
        ))
